import { Switch, Route, useLocation } from "wouter";
import { useEffect, useState, createContext, useContext, lazy, Suspense } from "react";
import { finalTranslationService } from "@/services/finalTranslationService";
import { finalCurrencyService } from "@/services/finalCurrencyService";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { AuthProvider } from "@/contexts/AuthContext";
import { CartProvider } from "@/contexts/CartContext";
import { LoadingProvider, useLoading } from "@/contexts/LoadingContext";
import { DashboardProvider } from "@/contexts/DashboardContext";
import Preloader from "@/components/Preloader";
import Navbar from "@/components/Navbar";
import Footer, { LanguageProvider, CurrencyProvider } from "@/components/Footer";
import GlobalSearch from "@/components/GlobalSearch";
import BackToTopButton from "@/components/BackToTopButton";
import BetaLock from "@/components/BetaLock";

import { withAppEditableContent } from "@/lib/withEditableContent";
// Import but don't use this directly as we'll wrap the entire app with it
// Keep the import to avoid breaking existing refs
import EditModeProvider from "@/components/EditModeProvider";

// Remove conflicting Window interface declarations as they're already defined

// Import critical pages directly for faster initial load
import Home from "@/pages/Home";
import StudioDetail from "@/pages/StudioDetail";
import Login from "@/pages/Login";
import Register from "@/pages/Register";

// Lazy load non-critical pages only
const EnhancedStudioDetail = lazy(() => import("@/pages/EnhancedStudioDetail"));
const BookStudio = lazy(() => import("@/pages/BookStudio"));
const StudioCategories = lazy(() => import("@/pages/studios/CategoriesPage"));
const CategoryPage = lazy(() => import("@/pages/studios/CategoryPage"));
const Dashboard = lazy(() => import("@/pages/dashboard/Dashboard"));
const StudioListings = lazy(() => import("@/pages/dashboard/StudioListings"));
const EditStudioLegacy = lazy(() => import("@/pages/dashboard/EditStudio"));
const MyStudios = lazy(() => import("@/pages/dashboard/MyStudios"));
const Payouts = lazy(() => import("@/pages/dashboard/Payouts"));
const StudioEdit = lazy(() => import("@/pages/owner-dashboard/listings/edit/[id]"));
const MessageCenter = lazy(() => import("@/pages/MessageCenter"));
const TestMessagingPage = lazy(() => import("@/pages/TestMessagingPage"));
const TestEmail = lazy(() => import("@/pages/TestEmail"));
const Admin = lazy(() => import("@/pages/Admin"));
const BlogAdmin = lazy(() => import("@/pages/BlogAdmin"));
const ShopAdmin = lazy(() => import("@/pages/admin/ShopAdmin"));
const SeoManagement = lazy(() => import("@/pages/admin/SeoManagement"));
const Blog = lazy(() => import("@/pages/Blog"));
const BlogPost = lazy(() => import("@/pages/BlogPost"));
import BlogCategory from "./pages/BlogCategory";
import Shop from "@/pages/Shop";
import Cart from "@/pages/Cart";
import Checkout from "@/pages/Checkout";
import CheckoutSuccess from "@/pages/CheckoutSuccess";
import VanityUrl from "@/pages/VanityUrl";
const Forum = lazy(() => import("@/pages/Forum"));
const ForumSubcategory = lazy(() => import("@/pages/ForumSubcategory"));
const ForumTopicPage = lazy(() => import("@/pages/ForumTopic"));
const ForumNewTopic = lazy(() => import("@/pages/ForumNewTopic"));
const Community = lazy(() => import("@/pages/Community"));
const About = lazy(() => import("@/pages/About"));
const Contact = lazy(() => import("@/pages/Contact"));
const Roadmap = lazy(() => import("@/pages/Roadmap"));
const Changelog = lazy(() => import("@/pages/Changelog"));
const Submit = lazy(() => import("@/pages/Submit"));
const MediaKit = lazy(() => import("@/pages/MediaKit"));
const Testimonials = lazy(() => import("@/pages/Testimonials"));
const Saved = lazy(() => import("@/pages/Saved"));
const Help = lazy(() => import("@/pages/Help"));
const NotFound = lazy(() => import("@/pages/not-found"));
// Support pages
const FAQs = lazy(() => import("@/pages/faqs"));
const FeedbackPage = lazy(() => import("@/pages/feedback"));
const SuggestListing = lazy(() => import("@/pages/suggest-listing"));
const SubmitTicket = lazy(() => import("@/pages/support/submit-ticket"));
const WhyJoin = lazy(() => import("@/pages/why-join"));
const Events = lazy(() => import("@/pages/Events"));
const CouponsDeals = lazy(() => import("@/pages/coupons-deals"));
const Partners = lazy(() => import("@/pages/Partners"));
const PressRoom = lazy(() => import("@/pages/PressRoom"));
const Promotions = lazy(() => import("@/pages/Promotions"));
// New pages
const UseCases = lazy(() => import("@/pages/UseCases"));
const Advertising = lazy(() => import("@/pages/Advertising"));
const Careers = lazy(() => import("@/pages/Careers"));
const ProjectWorkspace = lazy(() => import("@/pages/ProjectWorkspace"));
import Fidelity from "@/pages/Fidelity";
import Canvas from "@/pages/Canvas";
const SubmitListing = lazy(() => import("@/pages/SubmitListing"));
const Packages = lazy(() => import("@/pages/Packages"));
const UserListingsPage = lazy(() => import("@/pages/UserListingsPage"));
// Portfolio pages
const PortfoliosPage = lazy(() => import("@/pages/portfolios/index"));
const PortfolioDetailPage = lazy(() => import("@/pages/portfolios/[slug]"));
const PortfolioEditPage = lazy(() => import("@/pages/portfolios/edit/[id]"));
// Affiliate page
const Affiliate = lazy(() => import("@/pages/Affiliate"));
// Footer pages
import Privacy from "@/pages/Privacy";
import Terms from "@/pages/Terms";
import Cookies from "@/pages/cookies";
import Sitemap from "@/pages/Sitemap";
import RemovalsPage from "@/pages/RemovalsPage";
import Team from "@/pages/Team";
const DemoElements = lazy(() => import("@/pages/DemoElements"));
// Service pages
const Playback = lazy(() => import("@/pages/Playback"));
const Layouts = lazy(() => import("@/pages/Layouts"));
const Downtime = lazy(() => import("@/pages/Downtime"));
const Waves = lazy(() => import("@/pages/Waves"));
const PodcastDetail = lazy(() => import("@/pages/PodcastDetail"));
// Podcast pages
const Podcast = lazy(() => import("@/pages/Podcast"));
const PodcastEpisode = lazy(() => import("@/pages/PodcastEpisode"));
// Record Label pages
const RecordLabelDetail = lazy(() => import("@/pages/RecordLabelDetail"));
const RecordLabels = lazy(() => import("@/pages/RecordLabels"));
// Record Store pages
const RecordStoreDetail = lazy(() => import("@/pages/RecordStoreDetail"));
const RecordStores = lazy(() => import("@/pages/RecordStores"));
// Music Store pages
const MusicStoreDetail = lazy(() => import("@/pages/MusicStoreDetail"));
const MusicStores = lazy(() => import("@/pages/MusicStores"));
// Podcast2 page
const Podcast2 = lazy(() => import("@/pages/Podcast2"));
// Search page
const Search = lazy(() => import("@/pages/search"));
// Jobs Board pages
const Jobs = lazy(() => import("@/pages/Jobs"));
const JobDetail = lazy(() => import("@/pages/JobDetail"));
const JobPostPage = lazy(() => import("@/pages/JobPostPage"));
const JobPaymentSuccess = lazy(() => import("@/pages/JobPaymentSuccess"));
const JobManagePage = lazy(() => import("@/pages/JobManagePage"));
const JobsBrowse = lazy(() => import("@/pages/JobsBrowse"));
const JobEditor = lazy(() => import("@/pages/JobEditor"));
// Import our product pages
const VaultPage = lazy(() => import("@/pages/products/Vault"));
const BlurbsPage = lazy(() => import("@/pages/products/Blurbs"));
const SignalsPage = lazy(() => import("@/pages/products/Signals"));
const CanvasPage = lazy(() => import("@/pages/products/Canvas"));
const Introduction = lazy(() => import("@/pages/Introduction"));
// Import promoted page
const PromotedPage = lazy(() => import("@/pages/promoted"));
// Import search tool page
const SearchToolPage = lazy(() => import("@/pages/SearchTool"));
// Import the new category-related pages
const CategoriesPage = lazy(() => import("@/pages/Categories"));
const PhotographersPage = lazy(() => import("@/pages/Photographers"));
const VirtualToursPage = lazy(() => import("@/pages/VirtualTours"));
const ProfilePage = lazy(() => import("@/pages/ProfilePage"));
// Cart, checkout and related pages are already imported above

// WebSocket context for real-time updates
type WebSocketContextType = {
  socket: WebSocket | null;
  isConnected: boolean;
  sendMessage: (message: any) => void;
};

const WebSocketContext = createContext<WebSocketContextType>({
  socket: null,
  isConnected: false,
  sendMessage: () => {},
});

export const useWebSocket = () => useContext(WebSocketContext);

export const WebSocketProvider = ({ children }: { children: React.ReactNode }) => {
  const [socket, setSocket] = useState<WebSocket | null>(null);
  const [isConnected, setIsConnected] = useState(false);

  useEffect(() => {
    // Create WebSocket connection
    const protocol = window.location.protocol === "https:" ? "wss:" : "ws:";
    const wsUrl = `${protocol}//${window.location.host}/ws`;

    const ws = new WebSocket(wsUrl);

    ws.onopen = () => {
      console.log("WebSocket connected");
      setIsConnected(true);
    };

    ws.onclose = () => {
      console.log("WebSocket disconnected");
      setIsConnected(false);

      // Attempt to reconnect after delay
      setTimeout(() => {
        console.log("Attempting to reconnect WebSocket...");
        setSocket(null);
      }, 3000);
    };

    ws.onerror = (error) => {
      console.error("WebSocket error:", error);
    };

    ws.onmessage = (event) => {
      try {
        const data = JSON.parse(event.data);
        // Handle messages from server
        if (data.type === "FORUM_UPDATE") {
          // Invalidate relevant queries to trigger data refresh
          if (data.payload?.topicId) {
            queryClient.invalidateQueries({ queryKey: [`/api/forum/topics/${data.payload.topicId}`] });
            queryClient.invalidateQueries({ queryKey: [`/api/forum/topics/${data.payload.topicId}/posts`] });
          }

          if (data.payload?.subcategoryId) {
            queryClient.invalidateQueries({ 
              queryKey: [`/api/forum/categories/${data.payload.categorySlug}/subcategories/${data.payload.subcategorySlug}`] 
            });
            queryClient.invalidateQueries({ 
              queryKey: [`/api/forum/categories/${data.payload.categorySlug}/subcategories/${data.payload.subcategorySlug}/topics`] 
            });
          }

          // Always refresh recent topics and popular topics
          queryClient.invalidateQueries({ queryKey: ["/api/forum/topics/recent"] });
          queryClient.invalidateQueries({ queryKey: ["/api/forum/topics/popular"] });
        }
      } catch (error) {
        console.error("Error parsing WebSocket message:", error);
      }
    };

    setSocket(ws);

    // Clean up the WebSocket connection
    return () => {
      if (ws && (ws.readyState === WebSocket.OPEN || ws.readyState === WebSocket.CONNECTING)) {
        ws.close();
      }
    };
  }, []);

  const sendMessage = (message: any) => {
    if (socket && socket.readyState === WebSocket.OPEN) {
      socket.send(JSON.stringify(message));
    } else {
      console.warn("WebSocket not connected. Message not sent:", message);
    }
  };

  return (
    <WebSocketContext.Provider value={{ socket, isConnected, sendMessage }}>
      {children}
    </WebSocketContext.Provider>
  );
};

// Navigation listener for automatic translation and currency conversion
function NavigationListener() {
  const [location] = useLocation();

  useEffect(() => {
    // Apply saved language translation on page navigation with multiple attempts
    const savedLanguage = localStorage.getItem("stereoplaces-language");
    if (savedLanguage && savedLanguage !== "english") {
      // Multiple translation attempts to catch all content
      const translateAttempts = [100, 300, 500, 1000, 1500];
      translateAttempts.forEach(delay => {
        setTimeout(() => {
          finalTranslationService.translatePage(savedLanguage);
        }, delay);
      });
    }

    // Apply saved currency conversion on page navigation
    const savedCurrency = localStorage.getItem("stereoplaces-currency");
    if (savedCurrency && savedCurrency !== "usd") {
      setTimeout(() => {
        finalCurrencyService.refreshPrices();
      }, 300);
    }
  }, [location]);

  return null;
}

function Router() {
  const [location] = useLocation();
  const { isAppLoading, setAppLoading } = useLoading();
  const isDashboardRoute = location.startsWith("/owner-dashboard");
  const isAdminRoute = location.startsWith("/admin");
  const hideNavbarAndFooter = isDashboardRoute || isAdminRoute;

  // Performance tracking and optimization
  useEffect(() => {
    // Don't run this code during SSR
    if (typeof window === 'undefined') return;

    // Track page performance
    const trackPageLoadPerformance = () => {
      if (window.performance) {
        const perfData = window.performance.timing;
        const pageLoadTime = perfData.loadEventEnd - perfData.navigationStart;
        console.log(`Page load time: ${pageLoadTime}ms`);

        // Mark as loaded after critical resources
        if (pageLoadTime > 0) {
          setAppLoading(false);
        }
      }
    };

    // Set up performance monitoring
    const setupPerformanceMonitoring = () => {
      // Set up performance observer for navigation timing if available
      if (typeof window !== 'undefined' && 'PerformanceObserver' in window) {
        const perfObserver = new PerformanceObserver((list) => {
          const entries = list.getEntries();
          entries.forEach((entry) => {
            if (entry.entryType === 'navigation') {
              const navEntry = entry as PerformanceNavigationTiming;
              const loadTime = navEntry.loadEventEnd - navEntry.startTime;
              console.log(`Navigation load time: ${loadTime}ms`);

              // After 300ms or when navigation is complete, set as loaded
              if (loadTime > 0 || navEntry.loadEventEnd > 0) {
                setTimeout(() => setAppLoading(false), 300);
              }
            }
          });
        });

        try {
          perfObserver.observe({ entryTypes: ['navigation'] });
        } catch (e) {
          // Fallback for browsers not supporting PerformanceObserver
          window.addEventListener('load', trackPageLoadPerformance);
        }
      } else if (typeof window !== 'undefined') {
        // Fallback for older browsers
        window.addEventListener('load', trackPageLoadPerformance);

        // Set a timeout to ensure preloader doesn't hang indefinitely
        setTimeout(() => setAppLoading(false), 1500);
      }
    };

    // Execute the performance monitoring setup
    setupPerformanceMonitoring();

    // Preload critical resources
    const preloadResources = () => {
      // Preconnect to API domain (already same origin, but good practice)
      const linkPreconnect = document.createElement('link');
      linkPreconnect.rel = 'preconnect';
      linkPreconnect.href = window.location.origin;
      document.head.appendChild(linkPreconnect);

      // Preload critical CSS
      const linkPreload = document.createElement('link');
      linkPreload.rel = 'preload';
      linkPreload.as = 'style';
      linkPreload.href = '/src/index.css';
      document.head.appendChild(linkPreload);
    };

    preloadResources();

    return () => {
      window.removeEventListener('load', trackPageLoadPerformance);
    };
  }, [setAppLoading]);

  // Scroll to top on route change
  useEffect(() => {
    // Force immediate scroll to top without animation
    window.scrollTo({
      top: 0,
      left: 0,
      behavior: 'auto'
    });

    // Add a timeout to ensure scroll happens after render
    const timeoutId = setTimeout(() => {
      window.scrollTo({
        top: 0,
        left: 0,
        behavior: 'auto'
      });
    }, 0);

    return () => clearTimeout(timeoutId);
  }, [location]);

  return (
    <>
      <NavigationListener />
      {!isAdminRoute && <Preloader isLoading={isAppLoading} />}
      <div className="flex flex-col min-h-screen">
        {!hideNavbarAndFooter && <Navbar />}
        <main className="flex-grow">
          <Suspense fallback={<div className="flex items-center justify-center min-h-screen"></div>}>
            <Switch>
              <Route path="/" component={Home} />
              {/* Use our enhanced studio detail page */}
              <Route path="/studios/:id" component={EnhancedStudioDetail} />
              {/* Keep the original for reference */}
              <Route path="/studios/original/:id" component={({ params }) => (
                <StudioDetail id={params.id} />
              )} />
              {/* Studio categories pages */}
              <Route path="/studios/categories" component={StudioCategories} />
              <Route path="/studios/category/:categoryId" component={CategoryPage} />
              {/* Booking and checkout page */}
              <Route path="/book/:id" component={BookStudio} />
              {/* Studio Finder Tool */}
              <Route path="/searchtool" component={SearchToolPage} />
              {/* Auth Pages */}
              <Route path="/login" component={Login} />
              <Route path="/register" component={Register} />

              {/* Portfolio pages */}
              <Route path="/portfolios" component={PortfoliosPage} />
              <Route path="/portfolios/edit/:id" component={PortfolioEditPage} />
              <Route path="/portfolios/:slug" component={PortfolioDetailPage} />

              {/* Owner Dashboard Routes */}
              <Route path="/owner-dashboard" component={Dashboard} />
              <Route path="/owner-dashboard/my-studios" component={MyStudios} />
              <Route path="/owner-dashboard/listings" component={StudioListings} />
              <Route path="/owner-dashboard/listings/new" component={lazy(() => import("@/pages/owner-dashboard/listings/new"))} />
              <Route path="/owner-dashboard/listings/edit/:id" component={StudioEdit} />
              <Route path="/owner-dashboard/payouts" component={Payouts} />
              <Route path="/owner-dashboard/messages" component={lazy(() => import("@/pages/dashboard/Messages"))} />
              <Route path="/owner-dashboard/bookings" component={lazy(() => import("@/pages/dashboard/Bookings"))} />

              {/* Opportunities Routes */}
              <Route path="/owner-dashboard/get-interviewed" component={lazy(() => import("@/pages/dashboard/GetInterviewed"))} />
              <Route path="/owner-dashboard/boost-listing" component={lazy(() => import("@/pages/dashboard/BoostListing"))} />
              <Route path="/owner-dashboard/get-featured" component={lazy(() => import("@/pages/dashboard/GetFeatured"))} />

              {/* Account Routes */}
              <Route path="/owner-dashboard/profile" component={lazy(() => import("@/pages/dashboard/Profile"))} />
              <Route path="/owner-dashboard/settings" component={lazy(() => import("@/pages/dashboard/Settings"))} />
              <Route path="/owner-dashboard/support" component={lazy(() => import("@/pages/dashboard/Support"))} />

              {/* Messaging Routes */}
              <Route path="/messages" component={MessageCenter} />
              <Route path="/test-messaging" component={TestMessagingPage} />
              <Route path="/test-email" component={TestEmail} />

              {/* Project Workspace Route */}
              <Route path="/projects" component={ProjectWorkspace} />
              <Route path="/projects/:id" component={ProjectWorkspace} />

              {/* Blog Routes */}
              <Route path="/blog/category/:category" component={BlogCategory} />
              <Route path="/blog/:slug" component={BlogPost} />
              <Route path="/blog" component={Blog} />
              {/* Podcast Routes */}
              <Route path="/podcast/:id" component={PodcastEpisode} />
              <Route path="/podcast" component={Podcast} />
              {/* Record Label Routes */}
              <Route path="/record-labels" component={RecordLabels} />
              <Route path="/label/:id" component={RecordLabelDetail} />
              {/* Record Store Routes */}
              <Route path="/record-stores" component={RecordStores} />
              <Route path="/store/:id" component={RecordStoreDetail} />
              {/* Music Store Routes */}
              <Route path="/music-stores" component={MusicStores} />
              <Route path="/musicstore/:id" component={MusicStoreDetail} />
              {/* Podcast2 Route */}
              <Route path="/podcast2" component={Podcast2} />
              {/* Fidelity Route */}
              <Route path="/fidelity" component={Fidelity} />
              {/* Canvas Route */}
              <Route path="/canvas" component={Canvas} />

              {/* Shop Routes */}
              <Route path="/shop" component={Shop} />
              <Route path="/cart" component={Cart} />
              <Route path="/checkout" component={Checkout} />
              <Route path="/checkout/success" component={CheckoutSuccess} />
              <Route path="/vanity-url" component={VanityUrl} />

              {/* Community (Social Feed) Routes */}
              <Route path="/community" component={Community} />

              {/* Forum Routes */}
              <Route path="/forum" component={Forum} />
              <Route path="/forum/new-topic" component={ForumNewTopic} />
              <Route path="/forum/:categorySlug/:subcategorySlug/new-topic" component={ForumNewTopic} />
              <Route path="/forum/:categorySlug/:subcategorySlug" component={ForumSubcategory} />
              <Route path="/forum/:categorySlug/:subcategorySlug/:topicSlug" component={ForumTopicPage} />

              {/* Admin Route */}
              <Route path="/admin" component={Admin} />
              <Route path="/admin/blog" component={BlogAdmin} />
              <Route path="/admin/studio-approvals" component={lazy(() => import("@/pages/admin/studio-approvals"))} />
              <Route path="/admin/shop" component={ShopAdmin} />
              <Route path="/admin/products" component={lazy(() => import("@/pages/admin/products"))} />
              <Route path="/admin/orders" component={lazy(() => import("@/pages/admin/orders"))} />
              <Route path="/admin/seo" component={SeoManagement} />

              {/* New Content Pages */}
              <Route path="/about" component={About} />
              <Route path="/contact" component={Contact} />
              <Route path="/roadmap" component={Roadmap} />
              <Route path="/changelog" component={Changelog} />
              <Route path="/submit" component={Submit} />
              <Route path="/studio/submit" component={Submit} />
              <Route path="/studio/edit/:id" component={StudioEdit} />
              <Route path="/dashboard/studios" component={MyStudios} />
              <Route path="/mediakit" component={MediaKit} />
              <Route path="/testimonials" component={Testimonials} />
              <Route path="/saved" component={Saved} />
              <Route path="/help" component={Help} />
              {/* Helpdesk Routes */}
              <Route path="/helpdesk" component={lazy(() => import("@/pages/helpdesk"))} />
              <Route path="/helpdesk/categories/:slug" component={lazy(() => import("@/pages/helpdesk/categories/[slug]"))} />
              <Route path="/helpdesk/articles/:slug" component={lazy(() => import("@/pages/helpdesk/articles/[slug]"))} />
              <Route path="/helpdesk/contact" component={lazy(() => import("@/pages/helpdesk/contact"))} />

              {/* Support pages */}
              <Route path="/submit-ticket" component={SubmitTicket} />
              <Route path="/faqs" component={FAQs} />
              <Route path="/feedback" component={FeedbackPage} />
              <Route path="/suggest-listing" component={SuggestListing} />
              <Route path="/why-join" component={WhyJoin} />
              <Route path="/coupons-deals" component={CouponsDeals} />
              <Route path="/events" component={Events} />
              <Route path="/partners" component={Partners} />
              <Route path="/press-room" component={PressRoom} />
              <Route path="/promotions" component={Promotions} />

              {/* New Content Pages */}
              <Route path="/use-cases" component={UseCases} />
              <Route path="/advertising" component={Advertising} />
              <Route path="/careers" component={Careers} />
              <Route path="/affiliate" component={Affiliate} />
              <Route path="/fidelity" component={Fidelity} />
              <Route path="/submit-listing" component={SubmitListing} />
              <Route path="/categories" component={CategoriesPage} />
              <Route path="/photographers" component={PhotographersPage} />
              <Route path="/virtual-tours" component={VirtualToursPage} />
              <Route path="/profile" component={ProfilePage} />
              <Route path="/profile/:id" component={ProfilePage} />
              <Route path="/account/profile/:id" component={ProfilePage} />
              <Route path="/account/profile" component={ProfilePage} />
              <Route path="/account/listings" component={UserListingsPage} />

              {/* Product Routes */}
              <Route path="/vault" component={VaultPage} />
              <Route path="/blurbs" component={BlurbsPage} />
              <Route path="/signals" component={SignalsPage} />
              <Route path="/introduction" component={Introduction} />
              <Route path="/canvas" component={CanvasPage} />

              {/* Search */}
              <Route path="/search" component={Search} />

              {/* Footer Pages */}
              <Route path="/privacy" component={Privacy} />
              <Route path="/terms" component={Terms} />
              <Route path="/cookies" component={Cookies} />
              <Route path="/sitemap" component={Sitemap} />
              <Route path="/removals" component={RemovalsPage} />

              {/* Service Pages */}
              <Route path="/playback" component={Playback} />
              <Route path="/layouts" component={Layouts} />
              <Route path="/downtime" component={Downtime} />
              <Route path="/packages" component={Packages} />

              {/* Waves (Podcast) Routes */}
              <Route path="/waves" component={Waves} />
              <Route path="/waves/:slug" component={PodcastDetail} />

              {/* Jobs Board Routes */}
              <Route path="/jobs" component={Jobs} />
              <Route path="/jobs/browse" component={JobsBrowse} />
              <Route path="/jobs/post" component={JobPostPage} />
              <Route path="/jobs/edit/:id" component={JobEditor} />
              <Route path="/jobs/new" component={JobEditor} />
              <Route path="/jobs/success" component={JobPaymentSuccess} />
              <Route path="/jobs/manage" component={JobManagePage} />
              <Route path="/jobs/manage/:id" component={JobManagePage} />
              <Route path="/jobs/:slug" component={JobDetail} />
              
              {/* Team Route */}
              <Route path="/team" component={Team} />
              
              {/* Demo Elements Route */}
              <Route path="/demoelements" component={DemoElements} />

              <Route component={NotFound} />
            </Switch>
          </Suspense>
        </main>
        {!hideNavbarAndFooter && (
          <>
            <Footer />
            <BackToTopButton />
          </>
        )}
      </div>
    </>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <LoadingProvider>
        <LanguageProvider>
          <CurrencyProvider>
            <AuthProvider>
              <CartProvider>
                <WebSocketProvider>
                  <EditModeProvider>
                    <TooltipProvider>
                      <DashboardProvider>
                        <BetaLock>
                          <Toaster />
                          <Router />
                        </BetaLock>
                      </DashboardProvider>
                    </TooltipProvider>
                  </EditModeProvider>
                </WebSocketProvider>
              </CartProvider>
            </AuthProvider>
          </CurrencyProvider>
        </LanguageProvider>
      </LoadingProvider>
    </QueryClientProvider>
  );
}

// Wrap the entire app with edit mode functionality
export default withAppEditableContent(App);